%%
% iGEM 2011, Team Synergy, Edinburgh
% Modelling the kinetic outcome of enzamatic reactions
% File written by Yassen Abbas
% File last modified 07/09/2011

%% 
% Variable dictionary
% EH                     Enzyme Hydrolysis 
% E1max                  Maximum mass of enzyme 1 that can be absorbed onto 
%                        a unit mass of substrate 
% E2max                  Maximum mass of enzyme 2 that can be absorbed onto
%                        a unit mass of substrate
% r1                     Cellulose to Cellobiose reaction with competitive 
%                        Glucose, Cellobiose and Xylose inhibition
% r2                     Cellulose to Glucose Reaction with competitive 
%                        Glucose, Cellobiose and Xylose inhibition
% r3                     Cellobiose to Glucose Reaction with Competitive
%                        Glucose and Xylose Inhibition 
% S                      Substrate concentration
% t                      Time
% T                      Temperature
% k1r                    Reaction rate constant for reaction 1
% k2r                    Reaction rate constant for reaction 2
% k3r                    Reaction rate constant for reaction 3
% K1ad                   Dissociation constant for enzyme 1
% K2ad                   Dissociation constant for enxyme 2
% CBH                    exo-?-1,4-cellobiohydrolase
% EG                     endo-?-1,4-glucanase
% E1B                    Bound concentration of CBH and EG
% E2B                    Bound concentration of ?-glucosidase
% Rs                     Substrate Reactivity
% G                      Glucose concentration
% G2                     Cellobiose concentration 
% X                      Xylose Concentration 
% K1IG2                  Inhibition constant for Cellobiose 1
% K1IG                   Inhibition constant for Glucose 1
% K1IX                   Inhibition constant for xylose 1
% K2IG2                  Inhibiton constant for Cellobiose 2  
% K2IG                   Inhibition constant for Glucose 2
% K2IX                   Inhibition constant for Xylose 2
% K3M                    Substrate (cellobiose) saturation constants  
% K3IG                   Inhibition cosntant for Glucose 3
% K3IX                   Inhibition constant for xylose 3
% E_Ti                   Total enzyme concentration 
% E1F                    Free enzyme concentration of CHB and EG in
%                        solution
% E2F                    Free enzyme concentration of ?-glucosidase in
%                        solution 
% E_B1                   Bound concentration of CHB and EG
% E_B2                   Bound concentration of ?-glucosidase
% Ea                     Activation Engergy
% E1TZ                   Enzyme concentration of exo and endo-glucanase g/kg
% E2TZ                   Enzyme concenratin of Beta-glucosidase g/kg  
clear;
clc;

% Define global variables 

global k1r E1B E1TZ G K1ad K1IG Sc Sc2 G2 K2ad E2TZ E2max E1max Rs Rs2 G20 S0 K1IG2  K2IG X K1IX k2r K2IG2  K2IX k3r  K3M K3IG K3IX K1ad E1TZ E1max K2ad E2TZ E2max


% Define constants 
K1ad=0.4;
K2ad=0.1;
E1max= 0.06;
E2max=0.01;
Ea= -5540;
S0 = input('Enter the Concentration of Cellulose between 0.1 and 500 (g/kg): ')
Amt_Cellulose = S0;
G0=0.01;
G20=0.01;
E1TZ=input('Enter the Enzyme concentration of exo and endo-glucanase between 0.01 and 1 (g/kg): ')
E2TZ=input('Enter the Enzyme concentration of Beta-glucosidase 0.01 and 1 (g/kg): ')
Tz=input('Enter the Temperature you would like this to happen between 30 and 55 degrees Celcius  ): ') 
Sc=S0;
G2=G20;
G=G0;

% Substrate reactivity is an assumption based on figure 2
k1r45= 22.3;
k2r45 =7.18;
k3r45=285.5;
K1IG2= 0.015;
K1IG=0.1;
K1IX=0.1;
K2IG2=132;
K2IG=0.04;
K2IX=0.2;
K3M=24.3;
K3IG=3.9;
K3IX=201;
X=0;
R=1.987;

%%


% Define the Arrhenius law and calucalte the kinetic constants 
k1r= k1r45*exp(-Ea/R*(1/(273 + 45) - 1/(273 + Tz)));
k2r= k2r45*exp(-Ea/R*(1/(273 + 45) - 1/(273 + Tz)));
k3r= k3r45*exp(-Ea/R*(1/(273 + 45) - 1/(273 + Tz)));
 
 % Dfine constraints
 t_span = [0:0.1:1000];
 
 
 % Solve ODE for Cellulose
 [t,product]=ode45('iGEM_enzyme_function',t_span,[S0; G20; G0;]);
 
 
 


figure(1)
len_input = length(t_span);
semilogx(t,product(1:len_input,1),'r',t,product(1:len_input,2),'g', t,product(1:len_input,3),'b');
ylim([0 110]);
xlabel('Time (hours)');
ylabel('Amount of (g/kg)');
legend('Cellulose','Cellobiose','Glucose');





